@@ -4,8 +4,8 @@
 ## Author:      Mattia Barbon
 ## Modified by:
 ## Created:     17/03/2001
-## RCS-ID:      $Id: Html.pm,v 1.9 2005/02/26 11:31:02 mbarbon Exp $
-## Copyright:   (c) 2001-2005 Mattia Barbon
+## RCS-ID:      $Id: Html.pm,v 1.10 2006/09/24 15:04:25 mbarbon Exp $
+## Copyright:   (c) 2001-2006 Mattia Barbon
 ## Licence:     This program is free software; you can redistribute it and/or
 ##              modify it under the same terms as Perl itself
 #############################################################################
@@ -45,6 +45,8 @@ package Wx::HtmlContainerCell;  @ISA = qw(Wx::HtmlCell);
 package Wx::HtmlFontCell;       @ISA = qw(Wx::HtmlCell);
 package Wx::HtmlColourCell;     @ISA = qw(Wx::HtmlCell);
 package Wx::HtmlWidgetCell;     @ISA = qw(Wx::HtmlCell);
+package Wx::HtmlListBox;        @ISA = qw(Wx::VListBox);
+package Wx::PlHtmlListBox;      @ISA = qw(Wx::HtmlListBox);
 
 1;
 
